pub struct BatchScanner<'a> { /* private fields */ }Expand description
Lightweight batch scanner without font loading.
Use this for scan-only workflows (query, validate) where Layout is not needed.
Does not expose batch_compile() - use Batcher if you need compilation.
Implementations
Sourceimpl<'a> BatchScanner<'a>
impl<'a> BatchScanner<'a>
Sourcepub fn with_prelude(self, prelude: impl Into<String>) -> Self
pub fn with_prelude(self, prelude: impl Into<String>) -> Self
Add prelude code to inject at the beginning of each main file.
Sourcepub fn with_snapshot_from<P: AsRef<Path>>(
self,
paths: &[P],
) -> Result<Self, CompileError>
pub fn with_snapshot_from<P: AsRef<Path>>( self, paths: &[P], ) -> Result<Self, CompileError>
Pre-build a snapshot from files for efficient batch scanning.
Sourcepub fn batch_scan<P: AsRef<Path> + Sync>(
&self,
paths: &[P],
) -> Result<Vec<Result<ScanResult, CompileError>>, CompileError>
pub fn batch_scan<P: AsRef<Path> + Sync>( &self, paths: &[P], ) -> Result<Vec<Result<ScanResult, CompileError>>, CompileError>
Scan multiple files in parallel (Eval-only, no fonts).